From 38c7c09961c4226d4bf2cc935bf85f70763b74e8 Mon Sep 17 00:00:00 2001
From: Jason Hiser <jdh8d@virginia.edu>
Date: Sat, 16 Feb 2019 19:50:56 -0500
Subject: [PATCH] changed work-dir to avoid conflicts with other modules

Former-commit-id: 47b1904e6506b47275773a2d39e8994102766e2c
---
 cicd_tests/basic-pgms-orig.sh | 2 +-
 cicd_tests/do-build.sh        | 8 ++++----
 cicd_tests/do-clean.sh        | 2 +-
 cicd_tests/verify-fails.sh    | 2 +-
 cicd_tests/xform-cat.sh       | 2 +-
 cicd_tests/xform-ls.sh        | 2 +-
 6 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/cicd_tests/basic-pgms-orig.sh b/cicd_tests/basic-pgms-orig.sh
index 4d0b89cb2..c6a3170cf 100755
--- a/cicd_tests/basic-pgms-orig.sh
+++ b/cicd_tests/basic-pgms-orig.sh
@@ -2,7 +2,7 @@
 set -e
 set -x
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 source set_env_vars
 
 # internal tests that do not require transforming binaries
diff --git a/cicd_tests/do-clean.sh b/cicd_tests/do-clean.sh
index 95dc3b04b..06febc8bf 100755
--- a/cicd_tests/do-clean.sh
+++ b/cicd_tests/do-clean.sh
@@ -14,7 +14,7 @@ main()
 
 
 	if [[ $CICD_NIGHTLY == 1 ]] ; then
-		rm -rf $CICD_MODULE_WORK_DIR/peasoup_umbrella
+		rm -rf $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 	fi
 
 }
diff --git a/cicd_tests/verify-fails.sh b/cicd_tests/verify-fails.sh
index a6cae1e3e..1196ac546 100755
--- a/cicd_tests/verify-fails.sh
+++ b/cicd_tests/verify-fails.sh
@@ -2,7 +2,7 @@
 set -e
 set -x
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 source set_env_vars
 
 cd $PEASOUP_HOME/tests
diff --git a/cicd_tests/xform-cat.sh b/cicd_tests/xform-cat.sh
index 56d53520b..5afbcb8cc 100755
--- a/cicd_tests/xform-cat.sh
+++ b/cicd_tests/xform-cat.sh
@@ -1,4 +1,4 @@
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 
 set -e
 set -x
diff --git a/cicd_tests/xform-ls.sh b/cicd_tests/xform-ls.sh
index 748f01c5f..41d6fb8d7 100755
--- a/cicd_tests/xform-ls.sh
+++ b/cicd_tests/xform-ls.sh
@@ -2,7 +2,7 @@
 set -e
 set -x
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 source set_env_vars
 cd /tmp
 rm -rf ls.rida ped_ls
diff --git a/cicd_tests/do-build.sh b/cicd_tests/do-build.sh
index 2a6b0a8ec..a25af4cdd 100755
--- a/cicd_tests/do-build.sh
+++ b/cicd_tests/do-build.sh
@@ -18,14 +18,14 @@ main()
 	local orig_dir=$(pwd)
 
 	# puts peasoup_umbrella (and all submodules) in CICD_MODULE_WORK_DIR
-	cicd_setup_module_dependency allnp/peasoup_umbrella.git
+	cicd_setup_module_dependency allnp/peasoup_umbrella.git ps_pe_umbrella
 
 
-	# puts the version of peasoup_examples to test in peasoup_umbrella/peasoup_examples
-	cicd_put_module_in_tree peasoup_umbrella/peasoup_examples
+	# puts the version of peasoup_examples to test in ps_pe_umbrella/peasoup_examples
+	cicd_put_module_in_tree ps_pe_umbrella/peasoup_examples
 
 	# Build/run $PSZ, test result
-	cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+	cd $CICD_MODULE_WORK_DIR/ps_pe_umbrella
 	source set_env_vars
 	sudo ./get-peasoup-packages.sh all
 
-- 
GitLab